API Reference
=============

This section documents the API of the nanohub-dashboards library.

Dashboard
---------

.. autoclass:: nanohubdashboard.Dashboard
   :members:
   :undoc-members:
   :show-inheritance:

Graph
-----

.. autoclass:: nanohubdashboard.Graph
   :members:
   :undoc-members:
   :show-inheritance:

Plot
----

.. autoclass:: nanohubdashboard.Plot
   :members:
   :undoc-members:
   :show-inheritance:

DashboardClient
---------------

.. autoclass:: nanohubdashboard.DashboardClient
   :members:
   :undoc-members:
   :show-inheritance:

Configuration
-------------

.. autoclass:: nanohubdashboard.DashboardConfig
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: nanohubdashboard.Query
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: nanohubdashboard.Template
   :members:
   :undoc-members:
   :show-inheritance:
